@@ -178,8 +178,8 @@ class WorkOrder(workorder.WorkOrder):
     def update_progress(self, compute=True):
         if compute:
             done = sum(activity.duration for activity in self.reverse_done_for)
-            self.set_attributes(progress_done=done,
-                                progress_todo=max(0, self.budget - done))
+            self.cw_set(progress_done=done,
+                        progress_todo=max(0, self.budget - done))
         super(WorkOrder, self).update_progress(compute)
 
     # number of columns to display
