@@ -1,7 +1,8 @@
 from yams.buildobjs import (EntityType, RelationDefinition,
                             SubjectRelation, String, Float, Date)
 
-from cubicweb.schema import WorkflowableEntityType, ERQLExpression, RRQLExpression
+from cubicweb.schema import (
+    WorkflowableEntityType, ERQLExpression, RRQLExpression, RQLVocabularyConstraint)
 from cubes.workorder.schema import WorkOrder
 
 _ = unicode
