@@ -16,7 +16,7 @@ from logilab.mtconverter import xml_escape
 from cubicweb.utils import UStringIO
 from cubicweb.schema import display_name
 from cubicweb.predicates import (is_instance, empty_rset, multi_columns_rset,
-                                match_user_groups, score_entity)
+                                match_user_groups, score_entity, rql_condition)
 from cubicweb.view import AnyRsetView, EntityView, EntityAdapter
 from cubicweb.web import INTERNAL_FIELD_VALUE, stdmsgs, action
 from cubicweb.web.views import tableview, calendar, navigation, editcontroller
@@ -137,8 +137,9 @@ class ActivityCalendarItemView(calendar.CalendarItemView):
 class ValidateActivitiesAction(action.Action):
     __regid__ = 'validate-activities'
     __select__ = (action.Action.__select__
-                  & match_user_groups('managers')
                   & is_instance('Activity')
+                  & (match_user_groups('managers')
+                     | rql_condition('X done_for W, W owned_by U'))
                   & score_entity(lambda x: x.cw_adapt_to('IWorkflowable').state == 'pending'))
 
     category = 'mainactions'
@@ -156,13 +157,35 @@ class ValidateActivitiesAction(action.Action):
         msg = self._cw._('activities validated')
         return self._cw.user_callback(validate_cb, (eids,), msg)
 
-WORKORDER_CLOSED_STATES = ('validated', 'canceled')
+class ArchiveActivitiesAction(action.Action):
+    __regid__ = 'archive-activities'
+    __select__ = (action.Action.__select__
+                  & match_user_groups('managers')
+                  & is_instance('Activity')
+                  & score_entity(lambda x: x.cw_adapt_to('IWorkflowable').state == 'validated'))
+
+    category = 'mainactions'
+    title = _('archive activities')
+
+    def url(self):
+        if self.cw_row is None:
+            eids = [row[0] for row in self.cw_rset]
+        else:
+            eids = (self.cw_rset[self.cw_row][self.cw_col or 0],)
+        def archive_cb(req, eids):
+            for eid in eids:
+                entity = req.entity_from_eid(eid, 'Activity')
+                entity.cw_adapt_to('IWorkflowable').fire_transition('archive')
+        msg = self._cw._('activities archived')
+        return self._cw.user_callback(archive_cb, (eids,), msg)
+
+WORKORDER_CLOSED_STATES = ['validated', 'canceled']
 
 class MoveActivitiesAction(action.Action):
     __regid__ = 'move-activities'
     __select__ = (action.Action.__select__
-                  & match_user_groups('managers')
                   & is_instance('Activity')
+                  & rql_condition('X done_for W, W owned_by U')
                   & score_entity(lambda x: x.cw_adapt_to('IWorkflowable').state == 'pending'))
 
     category = 'mainactions'
@@ -186,6 +209,18 @@ class MoveActivitiesAction(action.Action):
         return self._cw.user_rql_callback((rql, {'y': workorder.eid}), msg)
 
 
+class ManagerMoveActivitiesAction(MoveActivitiesAction):
+    __select__ = (action.Action.__select__
+                  & match_user_groups('managers')
+                  & is_instance('Activity')
+                  & score_entity(lambda x: x.cw_adapt_to('IWorkflowable').state != 'archived'))
+
+    def actual_actions(self):
+        for item in self._cw.execute('Any W,WT,O,OT ORDERBY OT,WT WHERE W is WorkOrder, '
+                                     'O split_into W, O title OT, W title WT'
+                                     ).entities():
+            yield self.build_action(item.dc_long_title(), self.url(item))
+
 
 class ActivityIPrevNextAdapter(navigation.IPrevNextAdapter):
     __select__ = is_instance('Activity')
