@@ -69,26 +69,19 @@ def activity_done_for_choices(form, field, limit=None):
         else:
             options += [(req._('no workorders in state %s') % req._(open_state),
                          INTERNAL_FIELD_VALUE)]
-        return options
-    # for new entities, users will only see their matching resource
-    rql = ('DISTINCT Any WO,T WHERE WO is WorkOrder, WO title T, '
-           'WO in_state S, S name %(s)s, '
-           'WO todo_by R, R euser U')
-    rset = req.execute(rql+', U eid %(u)s', {'u': req.user.eid,
-                                             's': open_state})
-    if rset:
-        options += [(req._('your workorders'), None)]
-        options += sorted((entity.view('combobox'), unicode(entity.eid))
-                          for entity in rset.entities())
-    rset = req.execute(rql+', NOT U eid %(u)s', {'u': req.user.eid,
+    else:
+        # for new entities, users will only see their matching resource
+        rql = ('DISTINCT Any WO,T WHERE WO is WorkOrder, WO title T, '
+               'WO in_state S, S name %(s)s, '
+               'WO todo_by R, R euser U')
+        rset = req.execute(rql+', U eid %(u)s', {'u': req.user.eid,
                                                  's': open_state})
-    if rset:
-        options += [(req._('other workorders'), None)]
-        options += sorted((entity.view('combobox'), unicode(entity.eid))
-                          for entity in rset.entities())
-    if not options:
-        options += [(req._('no workorders'),
-                     INTERNAL_FIELD_VALUE)]
+        if rset:
+            options += sorted((entity.view('combobox'), unicode(entity.eid))
+                              for entity in rset.entities())
+        else:
+            options += [(req._('no workorders'),
+                         INTERNAL_FIELD_VALUE)]
     return options
 _affk.tag_subject_of(('Activity', 'done_for', '*'),
                      {'choices': activity_done_for_choices})
