@@ -6,7 +6,7 @@ from logilab.mtconverter import xml_escape
 from cubicweb.schema import display_name
 from cubicweb.view import EntityView
 from cubicweb.uilib import toggle_link
-from cubicweb.selectors import is_instance, one_line_rset
+from cubicweb.predicates import is_instance, one_line_rset
 from cubicweb.web.views import baseviews, primary, tabs
 
 from cubes.calendar.views import primaries as cal_primaries
@@ -55,7 +55,6 @@ class OrderPrimaryView(tabs.TabsMixin, primary.PrimaryView):
         self.wview('ic_progress_table_view', rset, 'null')
         self.render_tabs(self.tabs, self.default_tab, entity)
 
-
 class OrderOverviewView(EntityView):
     __regid__ = 'activity-overview'
     __select__ = is_instance('Order')
@@ -67,6 +66,9 @@ class OrderOverviewView(EntityView):
         rset = self._cw.execute(entity.rql_activities_groupby_resource, {'eid': entity.eid})
         headers = (_('Resource'), _('status'), _('time spent'), _('begin date'), _('end date'))
         self.wview('table', rset, 'null', headers=headers)
+        self.w('<div style="margin-top: 1em"><a href="%s">%s</a></div>' %
+               (self._cw.build_url(rql='Any A WHERE A done_for Y, X split_into Y, X eid %s' % entity.eid),
+                self._cw._('View all activities')))
 
 class OrderDetailView(EntityView):
     __regid__ = 'activity-details'
@@ -124,6 +126,9 @@ class WorkOrderOverviewView(EntityView):
         rset = self._cw.execute(entity.rql_activities_groupby_resource, {'eid': entity.eid})
         headers = (_('Resource'), _('status'), _('time spent'), _('begin date'), _('end date'))
         self.wview('table', rset, 'null', headers=headers)
+        self.w('<div style="margin-top: 1em"><a href="%s">%s</a></div>' %
+               (self._cw.build_url(rql='Any A WHERE A done_for X, X eid %s' % entity.eid),
+                self._cw._('view all activities')))
 
 
 class WorkOrderDetailView(EntityView):
@@ -193,7 +198,7 @@ class ResourceOverviewView(EntityView):
         entity = self.cw_rset.get_entity(row, col)
         rset = self._cw.execute(entity.rql_activities_groupby_workorder, {'eid': entity.eid})
         headers = (_('workorder'), _('status'), _('time spent'), _('begin date'), _('end date'))
-        self.wview('table', rset, 'null', headers=headers)#, subvid='tablecontext')
+        self.wview('table', rset, 'null', headers=headers, cellvids={0: 'outofcontext'})#, subvid='tablecontext')
 
 
 class ResourceDetailView(EntityView):
